vpnengine/pkiservice/src/pkisupport.cpp
branchRCL_3
changeset 22 9f4e37332ce5
parent 4 29b591713d44
child 23 473321461bba
--- a/vpnengine/pkiservice/src/pkisupport.cpp	Mon Jun 21 16:49:56 2010 +0300
+++ b/vpnengine/pkiservice/src/pkisupport.cpp	Thu Aug 19 10:54:34 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2008 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -263,7 +263,7 @@
     CleanupStack::PushL(newMapping);
     
     newMapping->SetMapDeletable(currentCertInfo->IsDeletable());
-    newMapping->SetMapApplications(iApplUids);
+    newMapping->SetMapApplicationsL(iApplUids);
     iApplUids.Reset();
     User::LeaveIfError(iMapper.AddMapping(newMapping));
             
@@ -433,7 +433,7 @@
 	if((iSupportStatus == KErrNotSupported) && 
 	    iToggleSwitch && (iInitState == EInitCompleteImportCerts))
 		{
 		// Some implementations of MIDP2 certstore return KErrNotSupported
 		// when calling iCertStore->Applications()
 		LOG_1("CPKISupport::RunL ignore error :%d", iSupportStatus);
 		iSupportStatus = KErrNone;		
@@ -767,25 +767,25 @@
 /**
     Removes all unnecessary certificates from the certificate
     list before generating the local mapping data.
-    More specifically, all MIDP2 and non X509 certificates are removed.
-    (MIDP2 certificates can never have a "VPN" trust setting.)
+    More specifically, all "Java Trust Root" and non X509 certificates are removed.
+    ("Java Trust Root" certificates can never have a "VPN" trust setting.)
     
     iListCleaned instance variable is used to limit the frequency
     of this cleanup - it's only necessary once, during PKI startup.
 */
 void CPKISupport::CleanupCertListL() 
     {
-    LOG_("Removing invalid certs (MIDP2 certs)");
+    LOG_("Removing invalid certs (\"Java Trust Root\" certs)");
 
     TInt certcount = iCerts.Count();
-    _LIT(KMidp2Label, "MIDP2");
+    _LIT(KJavaTrustRootLabel, "Java Trust Root");
     LOG_1("Total cert count, before cleanup: %d", iCerts.Count());
     RMPointerArray<CCTCertInfo> removedInfos;
     CleanupClosePushL(removedInfos);
     for (TInt i = certcount - 1; i >= 0; i--) 
         {
         CCTCertInfo* info = iCerts[i];
-        if (info->Label().Compare(KMidp2Label) == 0 ||
+        if (info->Label().Compare(KJavaTrustRootLabel) == 0 ||
             info->CertificateFormat() != EX509Certificate) 
             {
             // CCTCertInfo has private destructor
@@ -833,7 +833,7 @@
             break;
         case EInitRetrieveCertList:
             LOG_("CPKISupport::DoRunOperationL() EInitRetrieveCertList");
             // Cert list might be new. Remove all MIDP2 certificates first,
             // if it hasn't been already done
             CleanupCertListL();
             iInitState = EInitCompleteImportCerts;
@@ -1019,7 +1019,7 @@
                 case ESSComplete:
                     if(iCurrentFunction == PkiService::EApplications)
                         {
-                        iWrapper.SetApplications(iApplUids);
+                        iWrapper.SetApplicationsL(iApplUids);
                         }
                             
                     iSubState = ESSCompleteRequest;
@@ -1162,7 +1162,7 @@
 	iApplUids.Close();
 	for(TInt i = 0;i<aApplUids.Count();i++)
 		{
-		iApplUids.Append(aApplUids[i]);
+		iApplUids.AppendL(aApplUids[i]);
 		}
     SetCallerStatusPending( aStatus );
     SelectCertificateL(aLabel);
@@ -433,7 +433,7 @@
 	    iToggleSwitch && (iInitState == EInitCompleteImportCerts))
 		{
-		// Some implementations of MIDP2 certstore return KErrNotSupported
+		// Some implementations of "Java Trust Root" certstore return KErrNotSupported
 		// when calling iCertStore->Applications()
 		LOG_1("CPKISupport::RunL ignore error :%d", iSupportStatus);
@@ -833,7 +833,7 @@
         case EInitRetrieveCertList:
             LOG_("CPKISupport::DoRunOperationL() EInitRetrieveCertList");
-            // Cert list might be new. Remove all MIDP2 certificates first,
+            // Cert list might be new. Remove all "Java Trust Root" certificates first,
             // if it hasn't been already done
             CleanupCertListL();